==> rumdl-0.0.134.tar.gz: rumdl-0.0.134/tests/lsp_mkdocs_flavor_test.rs <==
//! Test that LSP properly respects the markdown flavor configuration
//! This prevents regression of issues where LSP hardcoded MarkdownFlavor::Standard

#![allow(deprecated)] // root_path is deprecated but required for InitializeParams

use tower_lsp::lsp_types::*;
use tower_lsp::{LanguageServer, LspService};

use rumdl_lib::lsp::server::RumdlLanguageServer;

/// Test that LSP respects MkDocs flavor for linting
#[tokio::test]
async fn test_lsp_respects_mkdocs_flavor() {
    let (service, _socket) = LspService::new(RumdlLanguageServer::new);

    // Initialize with a config that sets MkDocs flavor
    // Note: In real usage, this would be loaded from a .rumdl.toml file with:
    // [global]
    // flavor = "mkdocs"
    let init_params = InitializeParams {
        process_id: None,
        root_path: None, // Deprecated but required
        root_uri: Some(Url::parse("file:///test").unwrap()),
        initialization_options: None,
        capabilities: ClientCapabilities::default(),
        trace: None,
        workspace_folders: None,
        client_info: None,
        locale: None,
    };

    service.inner().initialize(init_params).await.unwrap();
    service.inner().initialized(InitializedParams {}).await;

    // Open a document with MkDocs-specific syntax
    let uri = Url::parse("file:///test/mkdocs.md").unwrap();
    let text = r#"# Test Document

!!! note "This is an MkDocs admonition"
    This should not trigger warnings when flavor is mkdocs

=== "Tab 1"
    Content in tab 1

=== "Tab 2"
    Content in tab 2

::: mkdocstrings
handler: python
options:
  show_source: true
:::

[^1]: This is a footnote specific to MkDocs

Some text with a footnote[^1]
"#;

    service
        .inner()
        .did_open(DidOpenTextDocumentParams {
            text_document: TextDocumentItem {
                uri: uri.clone(),
                language_id: "markdown".to_string(),
                version: 1,
                text: text.to_string(),
            },
        })
        .await;

    // Request diagnostics
    let diag_params = DocumentDiagnosticParams {
        text_document: TextDocumentIdentifier { uri: uri.clone() },
        identifier: None,
        previous_result_id: None,
        work_done_progress_params: WorkDoneProgressParams::default(),
        partial_result_params: PartialResultParams::default(),
    };

    let result = service.inner().diagnostic(diag_params).await;
    assert!(result.is_ok(), "Diagnostic request should succeed");

    // When properly configured with MkDocs flavor, these MkDocs-specific
    // constructs should not generate warnings. With Standard flavor,
    // they would likely generate various warnings about formatting.

    // Note: The actual test depends on the configuration being loaded.
    // In a real scenario with a .rumdl.toml file setting flavor = "mkdocs",
    // the MkDocs-specific syntax would be properly recognized.
}

/// Test that formatting respects the configured flavor
#[tokio::test]
async fn test_formatting_respects_flavor_config() {
    let (service, _socket) = LspService::new(RumdlLanguageServer::new);

    let init_params = InitializeParams {
        process_id: None,
        root_path: None, // Deprecated but required
        root_uri: Some(Url::parse("file:///test").unwrap()),
        initialization_options: None,
        capabilities: ClientCapabilities::default(),
        trace: None,
        workspace_folders: None,
        client_info: None,
        locale: None,
    };

    service.inner().initialize(init_params).await.unwrap();
    service.inner().initialized(InitializedParams {}).await;

    // Open document with content that might be formatted differently based on flavor
    let uri = Url::parse("file:///test/flavor_format.md").unwrap();
    let text = r#"# Test

!!! note
    MkDocs admonition content

Regular paragraph with trailing spaces
"#;

    service
        .inner()
        .did_open(DidOpenTextDocumentParams {
            text_document: TextDocumentItem {
                uri: uri.clone(),
                language_id: "markdown".to_string(),
                version: 1,
                text: text.to_string(),
            },
        })
        .await;

    // Request formatting
    let formatting_params = DocumentFormattingParams {
        text_document: TextDocumentIdentifier { uri },
        options: FormattingOptions {
            tab_size: 4,
            insert_spaces: true,
            properties: std::collections::HashMap::new(),
            trim_trailing_whitespace: Some(true),
            insert_final_newline: Some(true),
            trim_final_newlines: Some(true),
        },
        work_done_progress_params: WorkDoneProgressParams::default(),
    };

    let result = service.inner().formatting(formatting_params).await;
    assert!(result.is_ok(), "Formatting should succeed");

    // The formatting should respect the flavor configuration
    // With MkDocs flavor, the admonition syntax should be preserved
    // With Standard flavor, it might be treated differently
}

/// Test that code actions respect the configured flavor
#[tokio::test]
async fn test_code_actions_respect_flavor() {
    let (service, _socket) = LspService::new(RumdlLanguageServer::new);

    let init_params = InitializeParams {
        process_id: None,
        root_path: None, // Deprecated but required
        root_uri: Some(Url::parse("file:///test").unwrap()),
        initialization_options: None,
        capabilities: ClientCapabilities::default(),
        trace: None,
        workspace_folders: None,
        client_info: None,
        locale: None,
    };

    service.inner().initialize(init_params).await.unwrap();
    service.inner().initialized(InitializedParams {}).await;

    // Open document
    let uri = Url::parse("file:///test/actions.md").unwrap();
    let text = "# Heading\n\nContent with issues   \n";

    service
        .inner()
        .did_open(DidOpenTextDocumentParams {
            text_document: TextDocumentItem {
                uri: uri.clone(),
                language_id: "markdown".to_string(),
                version: 1,
                text: text.to_string(),
            },
        })
        .await;

    // Request code actions
    let action_params = CodeActionParams {
        text_document: TextDocumentIdentifier { uri },
        range: Range {
            start: Position { line: 2, character: 0 },
            end: Position { line: 2, character: 20 },
        },
        context: CodeActionContext {
            diagnostics: vec![],
            only: None,
            trigger_kind: None,
        },
        work_done_progress_params: WorkDoneProgressParams::default(),
        partial_result_params: PartialResultParams::default(),
    };

    let result = service.inner().code_action(action_params).await;
    assert!(result.is_ok(), "Code action request should succeed");

    // Code actions should be generated based on the configured flavor
    // Different flavors might have different fixes available
}

==> rumdl-0.0.220.tar.gz: rumdl-0.0.220/tests/lsp_mkdocs_flavor_test.rs <==
//! Test that LSP properly respects the markdown flavor configuration
//! This prevents regression of issues where LSP hardcoded MarkdownFlavor::Standard

#![allow(deprecated)] // root_path is deprecated but required for InitializeParams

use tower_lsp::lsp_types::*;
use tower_lsp::{LanguageServer, LspService};

use rumdl_lib::lsp::server::RumdlLanguageServer;

/// Test that LSP respects MkDocs flavor for linting
#[tokio::test]
async fn test_lsp_respects_mkdocs_flavor() {
    let (service, _socket) = LspService::new(|client| RumdlLanguageServer::new(client, None));

    // Initialize with a config that sets MkDocs flavor
    // Note: In real usage, this would be loaded from a .rumdl.toml file with:
    // [global]
    // flavor = "mkdocs"
    let init_params = InitializeParams {
        process_id: None,
        root_path: None, // Deprecated but required
        root_uri: Some(Url::parse("file:///test").unwrap()),
        initialization_options: None,
        capabilities: ClientCapabilities::default(),
        trace: None,
        workspace_folders: None,
        client_info: None,
        locale: None,
    };

    service.inner().initialize(init_params).await.unwrap();
    service.inner().initialized(InitializedParams {}).await;

    // Open a document with MkDocs-specific syntax
    let uri = Url::parse("file:///test/mkdocs.md").unwrap();
    let text = r#"# Test Document

!!! note "This is an MkDocs admonition"
    This should not trigger warnings when flavor is mkdocs

=== "Tab 1"
    Content in tab 1

=== "Tab 2"
    Content in tab 2

::: mkdocstrings
handler: python
options:
  show_source: true
:::

[^1]: This is a footnote specific to MkDocs

Some text with a footnote[^1]
"#;

    service
        .inner()
        .did_open(DidOpenTextDocumentParams {
            text_document: TextDocumentItem {
                uri: uri.clone(),
                language_id: "markdown".to_string(),
                version: 1,
                text: text.to_string(),
            },
        })
        .await;

    // Request diagnostics
    let diag_params = DocumentDiagnosticParams {
        text_document: TextDocumentIdentifier { uri: uri.clone() },
        identifier: None,
        previous_result_id: None,
        work_done_progress_params: WorkDoneProgressParams::default(),
        partial_result_params: PartialResultParams::default(),
    };

    let result = service.inner().diagnostic(diag_params).await;
    assert!(result.is_ok(), "Diagnostic request should succeed");

    // When properly configured with MkDocs flavor, these MkDocs-specific
    // constructs should not generate warnings. With Standard flavor,
    // they would likely generate various warnings about formatting.

    // Note: The actual test depends on the configuration being loaded.
    // In a real scenario with a .rumdl.toml file setting flavor = "mkdocs",
    // the MkDocs-specific syntax would be properly recognized.
}

/// Test that formatting respects the configured flavor
#[tokio::test]
async fn test_formatting_respects_flavor_config() {
    let (service, _socket) = LspService::new(|client| RumdlLanguageServer::new(client, None));

    let init_params = InitializeParams {
        process_id: None,
        root_path: None, // Deprecated but required
        root_uri: Some(Url::parse("file:///test").unwrap()),
        initialization_options: None,
        capabilities: ClientCapabilities::default(),
        trace: None,
        workspace_folders: None,
        client_info: None,
        locale: None,
    };

    service.inner().initialize(init_params).await.unwrap();
    service.inner().initialized(InitializedParams {}).await;

    // Open document with content that might be formatted differently based on flavor
    let uri = Url::parse("file:///test/flavor_format.md").unwrap();
    let text = r#"# Test

!!! note
    MkDocs admonition content

Regular paragraph with trailing spaces
"#;

    service
        .inner()
        .did_open(DidOpenTextDocumentParams {
            text_document: TextDocumentItem {
                uri: uri.clone(),
                language_id: "markdown".to_string(),
                version: 1,
                text: text.to_string(),
            },
        })
        .await;

    // Request formatting
    let formatting_params = DocumentFormattingParams {
        text_document: TextDocumentIdentifier { uri },
        options: FormattingOptions {
            tab_size: 4,
            insert_spaces: true,
            properties: std::collections::HashMap::new(),
            trim_trailing_whitespace: Some(true),
            insert_final_newline: Some(true),
            trim_final_newlines: Some(true),
        },
        work_done_progress_params: WorkDoneProgressParams::default(),
    };

    let result = service.inner().formatting(formatting_params).await;
    assert!(result.is_ok(), "Formatting should succeed");

    // The formatting should respect the flavor configuration
    // With MkDocs flavor, the admonition syntax should be preserved
    // With Standard flavor, it might be treated differently
}

/// Test that code actions respect the configured flavor
#[tokio::test]
async fn test_code_actions_respect_flavor() {
    let (service, _socket) = LspService::new(|client| RumdlLanguageServer::new(client, None));

    let init_params = InitializeParams {
        process_id: None,
        root_path: None, // Deprecated but required
        root_uri: Some(Url::parse("file:///test").unwrap()),
        initialization_options: None,
        capabilities: ClientCapabilities::default(),
        trace: None,
        workspace_folders: None,
        client_info: None,
        locale: None,
    };

    service.inner().initialize(init_params).await.unwrap();
    service.inner().initialized(InitializedParams {}).await;

    // Open document
    let uri = Url::parse("file:///test/actions.md").unwrap();
    let text = "# Heading\n\nContent with issues   \n";

    service
        .inner()
        .did_open(DidOpenTextDocumentParams {
            text_document: TextDocumentItem {
                uri: uri.clone(),
                language_id: "markdown".to_string(),
                version: 1,
                text: text.to_string(),
            },
        })
        .await;

    // Request code actions
    let action_params = CodeActionParams {
        text_document: TextDocumentIdentifier { uri },
        range: Range {
            start: Position { line: 2, character: 0 },
            end: Position { line: 2, character: 20 },
        },
        context: CodeActionContext {
            diagnostics: vec![],
            only: None,
            trigger_kind: None,
        },
        work_done_progress_params: WorkDoneProgressParams::default(),
        partial_result_params: PartialResultParams::default(),
    };

    let result = service.inner().code_action(action_params).await;
    assert!(result.is_ok(), "Code action request should succeed");

    // Code actions should be generated based on the configured flavor
    // Different flavors might have different fixes available
}
